# WebHookPostModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project_id** | **str** |  | 
**event_type** | [**WebHookEventTypeModel**](WebHookEventTypeModel.md) |  | 
**url** | **str** |  | 
**request_type** | [**RequestTypeModel**](RequestTypeModel.md) |  | 
**headers** | **{str: (str,)}** |  | 
**query_parameters** | **{str: (str,)}** |  | 
**name** | **str** |  | 
**description** | **str, none_type** |  | [optional] 
**should_send_body** | **bool** |  | [optional] 
**is_enabled** | **bool** |  | [optional] 
**should_send_custom_body** | **bool** |  | [optional] 
**custom_body** | **str, none_type** |  | [optional] 
**should_replace_parameters** | **bool** |  | [optional] 
**should_escape_parameters** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


